const config = require('config')

const staffEmail = config.get('journal.staffEmail')

const getEmailCopy = ({ emailType, titleText, targetUserName, comments }) => {
  let paragraph
  let hasLink = true
  let hasIntro = true
  let hasSignature = true
  switch (emailType) {
    case 'he-assigned':
      hasIntro = false
      hasSignature = false
      paragraph = `${targetUserName} has invited you to serve as the Handling Editor for ${titleText}.<br/><br/>
        To review this manuscript and respond to the invitation, please visit the manuscript details page.`
      break
    case 'he-accepted':
      paragraph = `Dr. ${targetUserName} agreed to be a Handling Editor on ${titleText}. Please click on the link below to access the manuscript.`
      break
    case 'he-declined':
      paragraph = `Dr. ${targetUserName} has declined to be a Handling Editor on ${titleText}.<br/><br/>
      ${comments}`
      hasLink = false
      break
    case 'he-revoked':
      hasIntro = false
      hasLink = false
      hasSignature = false
      paragraph = `${targetUserName} has removed you from the role of Handling Editor for ${titleText}.<br/><br/>
        The manuscript will no longer appear in your dashboard. Please contact ${staffEmail} if you have any questions about this change.`
      break
    default:
      throw new Error(`The ${emailType} email type is not defined.`)
  }

  return { paragraph, hasLink, hasIntro, hasSignature }
}

module.exports = {
  getEmailCopy,
}
