const config = require('config')
const { services } = require('pubsweet-component-helper-service')

const { getEmailCopy } = require('./emailCopy')

const unsubscribeSlug = config.get('unsubscribe.url')

module.exports = {
  sendInvitedHEEmail: ({
    email,
    eicName,
    baseUrl,
    customId,
    titleText,
    isCanceled,
    handlingEditor,
  }) => {
    email.toUser = {
      email: handlingEditor.email,
    }

    email.content.subject = isCanceled
      ? `${customId}: Editor invitation cancelled`
      : `${customId}: Invitation to edit a manuscript`

    email.content.unsubscribeLink = services.createUrl(
      baseUrl,
      unsubscribeSlug,
      {
        id: handlingEditor.id,
      },
    )

    const { html, text } = email.getBody({
      body: getEmailCopy({
        titleText,
        targetUserName: eicName,
        emailType: isCanceled ? 'he-revoked' : 'he-assigned',
      }),
    })

    email.sendEmail({ html, text })
  },
  sendEiCEmail: async ({
    eic,
    email,
    baseUrl,
    comments,
    titleText,
    isAccepted,
    targetUserName,
    subjectBaseText,
  }) => {
    email.content.subject = `${subjectBaseText} Assignment Response`
    const emailType = isAccepted ? 'he-accepted' : 'he-declined'

    email.toUser = {
      email: eic.email,
      name: `${eic.firstName} ${eic.lastName}`,
    }

    email.content.unsubscribeLink = services.createUrl(
      baseUrl,
      unsubscribeSlug,
      {
        id: eic.id,
      },
    )

    const { html, text } = email.getBody({
      body: getEmailCopy({
        comments,
        emailType,
        titleText,
        targetUserName,
      }),
    })

    email.sendEmail({ html, text })
  },
}
